==> openstory-8.x-1.2.tar.gz: openstory/src/Plugin/rest/resource/DrupalFileService.php <==
<?php

namespace Drupal\openstory\Plugin\rest\resource;

use Drupal\Core\File\FileSystemInterface;
use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Psr\Log\LoggerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;

/**
 * Provides resources to work with files.
 *
 * @RestResource(
 *   id = "drupal_service_file",
 *   label = @Translation("Drupal File Service"),
 *   uri_paths = {
 *     "canonical" = "/drupal_file",
 *     "https://www.drupal.org/link-relations/create" = "/drupal_file/{fileName}"
 *   }
 * )
 */
class DrupalFileService extends ResourceBase {

  /**
   * A current user instance.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Constructs a Drupal\rest\Plugin\ResourceBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   A current user instance.
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, AccountProxyInterface $current_user, FileSystemInterface $file_system) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->currentUser = $current_user;
    $this->fileSystem = $file_system;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
        $configuration,
        $plugin_id,
        $plugin_definition,
        $container->getParameter('serializer.formats'),
        $container->get('logger.factory')->get('custom_rest'),
        $container->get('current_user'),
        $container->get('file_system')
    );
  }

  /**
   * Responds to entity POST requests and saves the new entity.
   *
   * @param string $fileName
   *   The file name.
   *
   * @return \Drupal\rest\ModifiedResourceResponse
   *   The HTTP response object.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   */
  public function post($fileName) {
    $fileId = $this->getFileFid($fileName);
    if (empty($fileId)) {
      if ($this->checkFileExists($fileName)) {
        $dir = "public://mediaLibrary";
        $destination = $dir . '/' . $fileName;
        $fileContent = file_get_contents($destination, TRUE);
        file_save_data($fileContent, $destination, FILE_EXISTS_REPLACE);
        $fileId = $this->getFileFid($fileName);
        return new ResourceResponse($fileId, 200);
      }
      else {
        throw new BadRequestHttpException('There is no file with this name.');
      }
    }
    else {
      return new ResourceResponse($fileId, 200);
    }

  }

  /**
   * Check if entity file exists.
   *
   * @param string $fileName
   *   The file name.
   *
   * @return bool
   *   Return if file exists or not.
   */
  public function checkFileExists($fileName) {
    $dir = $this->fileSystem->realpath(file_default_scheme() . "://");
    $file = $dir . '/mediaLibrary/' . $fileName;
    if (!file_exists($file)) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Get file fid.
   *
   * @param string $fileName
   *   The file name.
   *
   * @return array
   *   Return array containing fid.
   */
  public function getFileFid($fileName) {
    $query = \Drupal::entityQuery('file');
    $query->condition('filename', $fileName);
    $query->condition('status', 1);
    $fileId = $query->execute();
    return $fileId;
  }

}

==> openstory-8.x-2.4.tar.gz: openstory/src/Plugin/rest/resource/DrupalFileService.php <==
<?php

namespace Drupal\openstory\Plugin\rest\resource;

use Drupal\Core\File\FileSystemInterface;
use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Psr\Log\LoggerInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;

/**
 * Provides resources to work with files.
 *
 * @RestResource(
 *   id = "drupal_service_file",
 *   label = @Translation("Drupal File Service"),
 *   uri_paths = {
 *     "canonical" = "/drupal_file",
 *     "https://www.drupal.org/link-relations/create" = "/drupal_file/{fileName}"
 *   }
 * )
 */
class DrupalFileService extends ResourceBase {

  /**
   * A current user instance.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Constructs a Drupal\rest\Plugin\ResourceBase object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param array $serializer_formats
   *   The available serialization formats.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   A current user instance.
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, array $serializer_formats, LoggerInterface $logger, AccountProxyInterface $current_user, FileSystemInterface $file_system) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $serializer_formats, $logger);
    $this->currentUser = $current_user;
    $this->fileSystem = $file_system;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
        $configuration,
        $plugin_id,
        $plugin_definition,
        $container->getParameter('serializer.formats'),
        $container->get('logger.factory')->get('custom_rest'),
        $container->get('current_user'),
        $container->get('file_system')
    );
  }

  /**
   * Responds to entity POST requests and saves the new entity.
   *
   * @param string $fileName
   *   The file name.
   *
   * @return \Drupal\rest\ResourceResponse
   *   The HTTP response object.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\HttpException
   */
  public function post($fileName) {
    $fileId = $this->getFileFid($fileName);
    if (empty($fileId)) {
      if ($this->checkFileExists($fileName)) {
        $dir = "public://mediaLibrary";
        $destination = $dir . '/' . $fileName;
        $fileContent = file_get_contents($destination, TRUE);
        file_save_data($fileContent, $destination, FILE_EXISTS_REPLACE);
        $fileId = $this->getFileFid($fileName);
        return new ResourceResponse(['fileId' => array_pop($fileId)], 200);
      }
      else {
        throw new BadRequestHttpException('There is no file with this name.');
      }
    }
    else {
      return new ResourceResponse(['fileId' => array_pop($fileId)], 200);
    }

  }

  /**
   * Check if entity file exists.
   *
   * @param string $fileName
   *   The file name.
   *
   * @return bool
   *   Return if file exists or not.
   */
  public function checkFileExists($fileName) {
    $dir = $this->fileSystem->realpath(file_default_scheme() . "://");
    $file = $dir . '/mediaLibrary/' . $fileName;
    if (!file_exists($file)) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Get file fid.
   *
   * @param string $fileName
   *   The file name.
   *
   * @return array
   *   Return array containing fid.
   */
  public function getFileFid($fileName) {
    $query = \Drupal::entityQuery('file');
    $query->condition('filename', $fileName);
    $query->condition('status', 1);
    $fileId = $query->execute();
    return $fileId;
  }

}
